<?php
/**
 * Created by PhpStorm.
 * User: tuliomagalhaes
 * Date: 17/04/2015
 * Time: 10:36
 */

namespace Controller;

use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\File;
use Util\Utilities;
use Zeedhi\DevOps\Util\Utilities as DevopsUtilities;

class Attachment extends Simple {

    private $attachmentService;

    public function __construct(\Service\Attachment $attachmentService )
    {
        $this->attachmentService = $attachmentService;
    }

    public function getAttachment(Request\Filter $request, Response $response)
    {
        $filters = $request->getFilterCriteria()->getConditions();
        $entity = $filters[0]['columnName'] != 'ID' ? $filters[0]['columnName'] : 'project' ;
        $id = DevopsUtilities::getValueInFilterDataSourceByName($filters, $entity, true);
        $conditions = DevopsUtilities::createQueryFiltered($filters);
        $resources = $this->attachmentService->getDataSetForEditAttachment($id, $entity, $conditions);
        $response->addDataSet(new DataSet('Attachment', $resources));
    }

    
    public function newUploadDocumentTask(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $taskId = empty($row['taskId']) ? null : $row['taskId'] ;
            $document = empty($row['DOCUMENT'])? null :$row['DOCUMENT'];
            $this->attachmentService->addDocumentsTask($taskId,$document);
            $response->addNotification( new Response\Notification('Todos os arquivos foram salvos'));
        }catch (\Exception $e){
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }
    
    public function saveLog(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $taskId = empty($row['taskId']) ? null : $row['taskId'] ;
            $document = empty($row['DOCUMENT'])? null :$row['DOCUMENT'];
            $this->attachmentService->saveLog($taskId,$document);
            $response->addNotification( new Response\Notification('Todos os arquivos foram salvos'));
        }catch (\Exception $e){
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function getFullLog(Request\Filter $request, Response $response)
    {
        $conditions = $request->getFilterCriteria()->getConditions();
        $logFileName = empty($conditions[0]) ? '' : $conditions[0]['value'];
        try {
            $logFileContents = $this->attachmentService->getFullLog($logFileName);
            $logFileContents = utf8_encode($logFileContents);   
            $response->addDataSet(new DataSet('logFileContents', [$logFileContents]));
        } catch (\Exception $e) {
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_ERROR));
        }
    }
    
    public function newUploadDocumentProject(Request\DataSet $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $this->attachmentService->addDocumentsProject($row['projectId'],$row['DOCUMENT']);
            $response->addNotification( new Response\Notification('Todos os arquivos foram salvos'));
        }catch (\Exception $e){
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }
    
    public function downLoadAttachment(Request $request, Response $response)
    {
        try{
            $row = $request->getDataSet()->getRows();
            $row = $row[0];
            $attachmentId = $row['ID'];
            $this->attachmentService->downLoadAttachment($attachmentId);

        }catch (\Exception $e){
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }
    
    public function deleteAttachment(Request\DataSet $request, Response $response)
    {
        try{
            $rows = $request->getDataSet()->getRows();
            $this->attachmentService->deleteAttachment($rows);
            $response->addNotification(new Response\Notification('Arquivo apagado com sucesso.'));

        }catch (\Exception $e){
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }
    
    public function checkIfRelatedTasksHasSameAttachment(Request\Filter $request, Response $response)
    {
        try{
            $filter = $request->getFilterCriteria()->getConditions();
            $id = Utilities::getValueInFilterDataSourceByName($filter, "ATTACHMENT");
            $relatedTasks = $this->attachmentService->checkIfRelatedTasksHasSameAttachment($id);
            $response->addDataSet(new DataSet('relatedTasks', $relatedTasks));
        } catch (\Exception $e){
            $response->addMessage(new Response\Message($e->getMessage(), Response\Message::TYPE_WARNING));
        }
    }
} 